@@ -23,6 +23,32 @@ module adjustdata
  implicit none
 
 contains
+
+!----------------------------------------------------
+!
+!  specify data dependencies for adjust data
+!  procedures to ensure required quantities
+!  are read from the data file
+!
+!----------------------------------------------------
+subroutine get_adjust_data_dependencies(required)
+ use labels,        only:idustfrac,irho,ivx,ideltav
+ use settings_data, only:ndimV,UseFakeDustParticles
+ logical, intent(inout) :: required(0:)
+ integer :: i
+
+ ! if making fake dust particles, read epsilon and deltav
+ if (idustfrac > 0 .and. irho > 0 .and. UseFakeDustParticles) then
+    if (required(irho)) required(idustfrac) = .true.
+    if (ideltav > 0) then
+       do i=ivx,ivx+ndimV-1
+          if (required(i)) required(ideltav+i-ivx) = .true.
+       enddo
+       if (any(required(ivx:ivx+ndimV-1))) required(idustfrac) = .true.
+    endif
+ endif
+
+end subroutine get_adjust_data_dependencies
 !----------------------------------------------------
 !
 !  amend data after the data read based on
@@ -33,33 +59,33 @@ contains
 !
 !----------------------------------------------------
 subroutine adjust_data_codeunits
- use system_utils,    only:renvironment,envlist,ienvironment,lenvironment
- use labels,          only:ih,ix,ivx,label,get_sink_type,ipmass,idustfrac,irho
- use settings_data,   only:ncolumns,ndimV,icoords,ndim,debugmode,ntypes,iverbose,fakedust
+ use system_utils,    only:renvironment,envlist,ienvironment,lenvironment,ienvlist
+ use labels,          only:ih,ix,ivx,label,get_sink_type,ipmass,idustfrac,irho,labeltype
+ use settings_data,   only:ncolumns,ndimV,icoords,ndim,debugmode,ntypes,iverbose,UseFakeDustParticles
  use particle_data,   only:dat,npartoftype,iamtype
  use geometry,        only:labelcoord
  use filenames,       only:ifileopen,nstepsinfile
- use part_utils,      only:locate_first_two_of_type,locate_nth_particle_of_type,get_binary
+ use part_utils,      only:locate_first_two_of_type,locate_nth_particle_of_type,get_binary,got_particles_of_type
  use settings_render, only:ifastrender
- real :: hmin,dphi
+ real :: hmin,dphi,domega
  real, dimension(3) :: vsink,xyzsink,x0,v0
  character(len=20), dimension(3) :: list
  integer :: i,j,nlist,nerr,ierr,isink,isinkpos,itype
- integer :: isink1,isink2,ntot
- logical :: centreonsink
+ integer :: ntot,isink1,isink2,isinklist(2)
+ logical :: centreonsink,got_sinks,no_dust_particles
 
  !
  !--environment variable setting to enforce a minimum h
  !
- if (ih.gt.0 .and. ih.le.ncolumns) then
+ if (ih > 0 .and. ih <= ncolumns) then
     hmin = renvironment('SPLASH_HMIN_CODEUNITS',errval=-1.)
-    if (hmin.gt.0.) then
+    if (hmin > 0.) then
        if (.not.allocated(dat)) then
           print*,' INTERNAL ERROR: dat not allocated in adjust_data_codeunits'
           return
        endif
        print "(/,a,es10.3)",' >> SETTING MINIMUM H TO ',hmin
-       where (dat(:,ih,:) < hmin .and. dat(:,ih,:).gt.0.)
+       where (dat(:,ih,:) < hmin .and. dat(:,ih,:) > 0.)
           dat(:,ih,:) = hmin
        end where
        print "(a)",' >> Switching accelerated rendering ON'
@@ -70,27 +96,27 @@ subroutine adjust_data_codeunits
  !
  !--environment variable setting to subtract a mean velocity
  !
- if (ivx.gt.0 .and. ivx+ndimV-1.le.ncolumns) then
+ if (ivx > 0 .and. ivx+ndimV-1 <= ncolumns) then
     call envlist('SPLASH_VZERO_CODEUNITS',nlist,list)
     nerr = 0
-    if (nlist.gt.0 .and. nlist.lt.ndimV) then
+    if (nlist > 0 .and. nlist < ndimV) then
        print "(/,2(a,i1))",' >> ERROR in SPLASH_VZERO_CODEUNITS setting: number of components = ',nlist,', needs to be ',ndimV
        nerr = 1
-    elseif (nlist.gt.0) then
-       if (nlist.gt.ndimV) print "(a,i1,a,i1)",' >> WARNING! SPLASH_VZERO_CODEUNITS setting has ',nlist, &
+    elseif (nlist > 0) then
+       if (nlist > ndimV) print "(a,i1,a,i1)",' >> WARNING! SPLASH_VZERO_CODEUNITS setting has ',nlist, &
                                                ' components: using only first ',ndimV
        nerr = 0
        do i=1,ndimV
           read(list(i),*,iostat=ierr) v0(i)
-          if (ierr.ne.0) then
+          if (ierr /= 0) then
              print "(a)",' >> ERROR reading v'//trim(labelcoord(i,icoords))//&
                          ' component from SPLASH_VZERO_CODEUNITS setting'
              nerr = ierr
           endif
        enddo
-       if (nerr.eq.0) then
+       if (nerr==0) then
           print "(a)",' >> SUBTRACTING MEAN VELOCITY (from SPLASH_VZERO_CODEUNITS setting):'
-          if (.not.allocated(dat) .or. size(dat(1,:,1)).lt.ivx+ndimV-1) then
+          if (.not.allocated(dat) .or. size(dat(1,:,1)) < ivx+ndimV-1) then
              print*,' INTERNAL ERROR: dat not allocated in adjust_data_codeunits'
              return
           endif
@@ -100,29 +126,43 @@ subroutine adjust_data_codeunits
           enddo
        endif
     endif
-    if (nerr.ne.0) then
+    if (nerr /= 0) then
        print "(4x,a)",'SPLASH_VZERO_CODEUNITS setting not used'
     endif
  endif
- if (ndim.gt.0) then
+ if (ndim > 0) then
     !
     !--environment variable to corotate with first two sink particles
+    !  can be SPLASH_COROTATE=true (just picks first two sinks)
+    !      or SPLASH_COROTATE=1,3
     !
-    if (lenvironment('SPLASH_COROTATE')) then
+    isinklist = ienvlist('SPLASH_COROTATE',2)
+    got_sinks = all(isinklist > 0)
+    if (lenvironment('SPLASH_COROTATE') .or. got_sinks) then
        itype = get_sink_type(ntypes)
-       if (itype.gt.0) then
-          if (all(npartoftype(itype,:).lt.2)) then
+       if (itype > 0) then
+          if (all(npartoftype(itype,:) < 2)) then
              print "(a)",' ERROR: SPLASH_COROTATE set but less than 2 sink particles'
           else
-             if (iverbose.ge.1) print*
-             print "(a,i3,a)",' :: COROTATING FRAME WITH FIRST 2 SINKS from SPLASH_COROTATE setting'
+             if (iverbose >= 1) print*
+             if (got_sinks) then
+                print "(a,i3,a,i3,a)",' :: COROTATING FRAME WITH SINKS ',isinklist(1),&
+                                      ', ',isinklist(2),' from SPLASH_COROTATE setting'
+             else
+                print "(a)",' :: COROTATING FRAME WITH FIRST 2 SINKS from SPLASH_COROTATE setting'
+             endif
              do j=1,nstepsinfile(ifileopen)
-                !  find first two sink particles in the data
-                call locate_first_two_of_type(isink1,isink2,itype,iamtype(:,j),npartoftype(:,j),ntot)
+                if (got_sinks) then
+                   call locate_nth_particle_of_type(isinklist(1),isink1,itype,iamtype(:,j),npartoftype(:,j),ntot)
+                   call locate_nth_particle_of_type(isinklist(2),isink2,itype,iamtype(:,j),npartoftype(:,j),ntot)
+                else
+                   !  find first two sink particles in the data
+                   call locate_first_two_of_type(isink1,isink2,itype,iamtype(:,j),npartoftype(:,j),ntot)
+                endif
                 !  get properties of the binary
-                call get_binary(isink1,isink2,dat(:,:,j),x0,v0,dphi,ndim,ndimV,ncolumns,ix,ivx,ipmass,iverbose,ierr)
+                call get_binary(isink1,isink2,dat(:,:,j),x0,v0,dphi,domega,ndim,ndimV,ncolumns,ix,ivx,ipmass,iverbose,ierr)
                 !  rotate all the particles into this frame
-                if (ierr.eq.0) call rotate_particles(dat(:,:,j),ntot,dphi,x0(1:ndim),ndim,ndimV,v0)
+                if (ierr==0) call rotate_particles(dat(:,:,j),ntot,dphi,domega,x0(1:ndim),ndim,ndimV,v0)
              enddo
           endif
        else
@@ -137,32 +177,32 @@ subroutine adjust_data_codeunits
     !--can specify either just "true" for sink #1, or specify a number for a particular sink
     centreonsink = lenvironment('SPLASH_CENTRE_ON_SINK') .or. lenvironment('SPLASH_CENTER_ON_SINK')
     isink        = max(ienvironment('SPLASH_CENTRE_ON_SINK'),ienvironment('SPLASH_CENTER_ON_SINK'))
-    if (isink.gt.0 .or. centreonsink) then
-       if (isink.eq.0) isink = 1
+    if (isink > 0 .or. centreonsink) then
+       if (isink==0) isink = 1
        itype = get_sink_type(ntypes)
-       if (itype.gt.0) then
-          if (all(npartoftype(itype,:).lt.isink)) then
+       if (itype > 0) then
+          if (all(npartoftype(itype,:) < isink)) then
              print "(a,i10,a)",' ERROR: SPLASH_CENTRE_ON_SINK = ',isink,' but not enough sink particles'
           else
-             if (iverbose.ge.1) print*
-             if (isink.lt.10) then
+             if (iverbose >= 1) print*
+             if (isink < 10) then
                 print "(a,i1,a)",' :: CENTREING ON SINK ',isink,' from SPLASH_CENTRE_ON_SINK setting'
              else
                 print "(a,i3,a)",' :: CENTREING ON SINK ',isink,' from SPLASH_CENTRE_ON_SINK setting'
              endif
              do j=1,nstepsinfile(ifileopen)
                 call locate_nth_particle_of_type(isink,isinkpos,itype,iamtype(:,j),npartoftype(:,j),ntot)
-                if (isinkpos.eq.0) then
+                if (isinkpos==0) then
                    print "(a)",' ERROR: could not locate sink particle in dat array'
                 else
                    if (debugmode) print*,' SINK POSITION = ',isinkpos,npartoftype(1:itype,j)
                    !--make positions relative to sink particle
                    xyzsink(1:ndim) = dat(isinkpos,ix(1:ndim),j)
-                   if (iverbose.ge.1) print "(a,3(1x,es10.3))",' :: sink position =',xyzsink(1:ndim)
+                   if (iverbose >= 1) print "(a,3(1x,es10.3))",' :: sink position =',xyzsink(1:ndim)
                    !--make velocities relative to sink particle
-                   if (ivx.gt.0 .and. ivx+ndimV-1.le.ncolumns) then
+                   if (ivx > 0 .and. ivx+ndimV-1 <= ncolumns) then
                       vsink(1:ndimV) = dat(isinkpos,ivx:ivx+ndimV-1,j)
-                      if (iverbose.ge.1) print "(a,3(1x,es10.3))",' :: sink velocity =',vsink(1:ndimV)
+                      if (iverbose >= 1) print "(a,3(1x,es10.3))",' :: sink velocity =',vsink(1:ndimV)
                    else
                       vsink = 0.
                    endif
@@ -179,11 +219,13 @@ subroutine adjust_data_codeunits
  !
  !--fake a set of dust particles from the one-fluid dust formulation
  !
- if (idustfrac.gt.0 .and. irho.gt.0 .and.            &
-          .not.(lenvironment('SPLASH_BARYCENTRIC')   &
-          .or. lenvironment('NSPLASH_BARYCENTRIC'))) then
-    fakedust = .true.
-    call fake_twofluids(1,nstepsinfile(ifileopen),ndim,ndimV,dat,npartoftype,iamtype)
+ no_dust_particles = .not.got_particles_of_type('dust',labeltype,npartoftype)
+ if (idustfrac > 0 .and. irho > 0 .and. no_dust_particles) then
+    if (UseFakeDustParticles) then
+       call fake_twofluids(1,nstepsinfile(ifileopen),ndim,ndimV,dat,npartoftype,iamtype)
+    elseif (iverbose >= 1) then
+       print "(a)",' One fluid dust: set option in d) menu to make fake dust particles'
+    endif
  endif
 
 end subroutine adjust_data_codeunits
@@ -191,10 +233,10 @@ end subroutine adjust_data_codeunits
 !-----------------------------------------------------------------
 ! routine to rotate particles with a given cylindrical angle dphi
 !-----------------------------------------------------------------
-pure subroutine rotate_particles(dat,np,dphi,x0,ndim,ndimV,v0)
+pure subroutine rotate_particles(dat,np,dphi,domega,x0,ndim,ndimV,v0)
  use labels, only:ix,ivx
  integer, intent(in) :: np,ndim,ndimV
- real,    intent(in) :: dphi
+ real,    intent(in) :: dphi,domega
  real,    dimension(:,:), intent(inout) :: dat
  real, dimension(ndim), intent(in) :: x0
  real, dimension(ndimV), intent(in) :: v0
@@ -219,7 +261,7 @@ pure subroutine rotate_particles(dat,np,dphi,x0,ndim,ndimV,v0)
     if (ivx > 0) then
        vi = dat(i,ivx:ivx+ndimV-1) - v0
        vr = vi(1)*xi(1)/r + vi(2)*xi(2)/r
-       vphi = vi(1)*(-xi(2)/r) + vi(2)*xi(1)/r
+       vphi = (vi(1)*(-xi(2)/r) + vi(2)*xi(1)/r) - r*domega
        dat(i,ivx)   = vr*cosp - vphi*sinp
        dat(i,ivx+1) = vr*sinp + vphi*cosp
     endif
@@ -286,8 +328,7 @@ end subroutine shift_velocities
 !------------------------------------------------------
 subroutine fake_twofluids(istart,iend,ndim,ndimV,dat,npartoftype,iamtype)
  use params,         only:int1
- use labels,         only:idustfrac,idustfracsum, &
-                          irho,ix,ih,ipmass,ivx,ideltav,ideltavsum
+ use labels,         only:idustfrac,irho,ix,ih,ipmass,ivx,ideltav
  use mem_allocation, only:alloc
  use particle_data,  only:maxpart,maxstep,maxcol
  use settings_data,  only:iverbose,ndusttypes,idustfrac_plot,ideltav_plot
@@ -298,20 +339,20 @@ subroutine fake_twofluids(istart,iend,ndim,ndimV,dat,npartoftype,iamtype)
  integer :: ndust,jdust,ntoti,i,j
  integer :: idustfrac_temp,ideltav_temp
  real    :: rhodust,rhogas,rhotot,dustfraci,gasfraci,pmassgas,pmassdust,pmassj
- real, dimension(ndimV) :: veli,vgas,vdust,deltav,deltavsum
+ real, dimension(ndimV) :: veli,vgas,vdust,deltav
  logical :: use_vels
 
- if (idustfrac.gt.0 .and. irho.gt.0) then
+ if (idustfrac > 0 .and. irho > 0) then
     !
     !--determine which dust fraction is being used to create the fake dust particles
     !
     !if (iverbose >= 0) print*,' got dustfrac in column ',idustfrac
     if (ndusttypes>1) then
        if (idustfrac_plot == 0 ) then
-          idustfrac_temp = idustfracsum
-          idustfrac_plot = idustfracsum
-          ideltav_temp   = ideltavsum
-          ideltav_plot   = ideltavsum
+          idustfrac_temp = idustfrac
+          idustfrac_plot = idustfrac_plot
+          ideltav_temp   = ideltav
+          ideltav_plot   = ideltav
        else
           idustfrac_temp = idustfrac_plot
           ideltav_temp   = ideltav_plot
@@ -325,7 +366,7 @@ subroutine fake_twofluids(istart,iend,ndim,ndimV,dat,npartoftype,iamtype)
     !
     do i=istart,iend
        ntoti = sum(npartoftype(:,i))
-       if (.not.allocated(dat) .or. (ntoti + npartoftype(1,i)).gt.maxpart) then
+       if (.not.allocated(dat) .or. (ntoti + npartoftype(1,i)) > maxpart) then
           call alloc(ntoti + npartoftype(1,i),maxstep,maxcol,mixedtypes=.true.)
        endif
        if (npartoftype(2,i) > 0) cycle
@@ -336,49 +377,30 @@ subroutine fake_twofluids(istart,iend,ndim,ndimV,dat,npartoftype,iamtype)
           print*,' ERROR: idustfrac out of range: cannot create fake dust particles'
           return
        endif
-       use_vels = (ideltav_temp.gt.0 .and. ivx.gt.0 .and. ndimV.gt.0)
+       use_vels = (ideltav_temp > 0 .and. ivx > 0 .and. ndimV > 0)
        do j=1,ntoti
-          if (iamtype(j,i).eq.1) then
+          if (iamtype(j,i)==1) then
              ndust = ndust + 1 ! one dust particle for every gas particle
              rhotot  = dat(j,irho,i)
              dustfraci = dat(j,idustfrac_temp,i)
-             if (idustfracsum == 0) then
-                gasfraci = 1. - dustfraci
-             else
-                gasfraci = 1. - dat(j,idustfracsum,i)
-             endif
+             gasfraci = 1. - dustfraci
              rhogas  = rhotot*gasfraci
              rhodust = rhotot*dustfraci
              !--replace global properties with gas-only stuff
              dat(j,irho,i) = rhogas
+             dat(j,idustfrac,i) = 0.    ! dust fraction = 0 on gas particles
              !--copy x, smoothing length onto dust particle
              jdust = ntoti + ndust
 
              !--fill in dust properties
-             if (ndim.gt.0) dat(jdust,ix(1:ndim),i) = dat(j,ix(1:ndim),i)
-             if (ih.gt.0)   dat(jdust,ih,i)         = dat(j,ih,i)
-             if (irho.gt.0) dat(jdust,irho,i)       = rhodust
-             if (idustfracsum == 0) then
-                !--copy the dustfracion
-                dat(jdust,idustfrac,i) = dustfraci
-                if (ideltav /= 0) then
-                   !--copy the deltav's
-                   dat(jdust,ideltav:ideltav+ndimV-1,i) = dat(j,ideltav:ideltav+ndimV-1,i)
-                endif
-             else
-                !--copy the dustfracion
-                dat(jdust,idustfracsum:idustfracsum+ndusttypes,i) = &
-                    dat(j,idustfracsum:idustfracsum+ndusttypes,i)
-                !--copy the deltav's
-                if (ideltavsum /= 0) then
-                   dat(jdust,ideltavsum:ideltavsum+ndimV*(ndusttypes+1)-1,i) = &
-                              dat(j,ideltavsum:ideltavsum+ndimV*(ndusttypes+1)-1,i)
-                endif
-             endif
+             if (ndim > 0) dat(jdust,ix(1:ndim),i) = dat(j,ix(1:ndim),i)
+             if (ih > 0)   dat(jdust,ih,i)         = dat(j,ih,i)
+             if (irho > 0) dat(jdust,irho,i)       = rhodust
+             dat(jdust,idustfrac,i) = 1. ! dust fraction = 1 on dust particles
              iamtype(ntoti + ndust,i) = 2
 
              !--particle masses
-             if (ipmass.gt.0) then
+             if (ipmass > 0) then
                 pmassj    = dat(j,ipmass,i)
                 pmassgas  = pmassj*gasfraci
                 pmassdust = pmassj*dustfraci
@@ -390,21 +412,21 @@ subroutine fake_twofluids(istart,iend,ndim,ndimV,dat,npartoftype,iamtype)
              if (use_vels) then
                 veli(:)      = dat(j,ivx:ivx+ndimV-1,i)
                 deltav(:)    = dat(j,ideltav_temp:ideltav_temp+ndimV-1,i)
-                if (ndusttypes>1 .and. idustfrac_temp/=idustfracsum) then
-                   deltavsum(:) = dat(j,ideltavsum:ideltavsum+ndimV-1,i)
-                   vgas(:)      = veli(:) - (1. - gasfraci)*deltavsum(:)
-                   vdust(:)     = veli(:) + deltav(:) - (1. - gasfraci)*deltavsum(:)
-                else
-                   vgas(:)      = veli(:) - (1. - gasfraci)*deltav(:)
-                   vdust(:)     = veli(:) + gasfraci*deltav(:)
-                endif
+                vgas(:)      = veli(:) - (1. - gasfraci)*deltav(:)
+                vdust(:)     = veli(:) + gasfraci*deltav(:)
                 dat(j,ivx:ivx+ndimV-1,i)     = vgas(:)
                 dat(jdust,ivx:ivx+ndimV-1,i) = vdust(:)
+                if (ideltav /= 0) then
+                    !--set deltav to zero on gas and dust particles
+                    dat(j,ideltav_temp:ideltav_temp+ndimV-1,i) = deltav(:)
+                    dat(jdust,ideltav:ideltav+ndimV-1,i) = deltav(:)
+                 endif
+                !if (abs(deltav(1)) > 0.3) print*,' particle ',j,'->',jdust,' vg = ',vgas(:),' vd = ',vdust(:),' v = ',veli,deltav
              endif
           endif
        enddo
-       if (iverbose.ge.1) then
-          print "(a,i8,a)",' Creating ',ndust,' fake dust particles (set SPLASH_BARYCENTRIC=yes to plot barycentric values)'
+       if (iverbose >= 1) then
+          print "(a,i8,a)",' Creating ',ndust,' fake dust particles'
           if (.not.use_vels .and. ivx > 0) print "(a)",' WARNING: deltav not found in one fluid dust data: cannot get vels'
        endif
        npartoftype(2,i) = npartoftype(2,i) + ndust
