@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2018 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2019 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -25,6 +25,7 @@
 !  files to 3D gridded data.
 !-----------------------------------------------------------------
 module convert_grid
+ use params, only:doub_prec
  implicit none
  private
  public :: convert_to_grid
@@ -36,11 +37,11 @@ contains
 ! data output routines
 !-----------------------------------------------------------------
 subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,filename,&
-                           outformat,interpolateall)
+                           outformat,interpolateall,icols,rhogrid,dat3D)
  use labels,               only:label,labelvec,irho,ih,ipmass,ix,ivx,iBfirst,get_sink_type
  use limits,               only:lim,get_particle_subset
  use settings_units,       only:units,unit_interp
- use settings_data,        only:ndim,ndimV,UseTypeInRenderings,iRescale,required,debugmode,icoordsnew,xorigin
+ use settings_data,        only:ndim,ndimV,UseTypeInRenderings,iRescale,required,debugmode,icoordsnew,xorigin,iverbose
  use settings_part,        only:iplotpartoftype
  use settings_render,      only:npix,inormalise_interpolations,idensityweightedinterpolation,exact_rendering
  use params,               only:int1
@@ -54,6 +55,8 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  use params,               only:int8
  use geometry,             only:coord_is_length,igeom_cartesian,labelcoord,labelcoordsys
  use asciiutils,           only:strip
+ use timing,               only:wall_time,print_time
+ use filenames,            only:tagline
  integer, intent(in)                          :: ntypes,ncolumns
  integer, intent(in), dimension(:)            :: npartoftype
  integer(kind=int1), intent(in), dimension(:) :: itype
@@ -62,33 +65,41 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  real, intent(in), dimension(:)               :: masstype
  character(len=*), intent(in)                 :: filename,outformat
  logical, intent(in)                          :: interpolateall
+ integer, intent(in),  optional               :: icols(:)
+ real,    intent(out), allocatable, optional  :: rhogrid(:,:,:),dat3D(:,:,:)
  integer, parameter :: iunit = 89
  integer            :: ierr,i,k,ncolsgrid,ivec,nvec,iloc,j,nzero
  integer            :: npixx,ntoti,ninterp,isinktype
  character(len=40)  :: fmtstring
  character(len=64)  :: fmtstring1
 
- real, dimension(:,:,:), allocatable   :: datgrid
+ real(doub_prec), dimension(:,:,:), allocatable   :: datgrid
  real, dimension(:,:),   allocatable   :: datgrid2D
- real, dimension(:,:,:,:), allocatable :: datgridvec
+ real(doub_prec), dimension(:,:,:,:), allocatable :: datgridvec
  real, dimension(:,:,:),   allocatable :: datgridvec2D
  real, dimension(:), allocatable       :: weight
  real, dimension(3)    :: xmin,xmax
  real, dimension(3)    :: partmin,partmax,partmean
  real, dimension(3)    :: datmin,datmax,datmean
+ real(doub_prec)       :: dtime
+ real(doub_prec), dimension(3) :: xmind,xmaxd
  integer, dimension(3) :: npixels
  integer(kind=int8), dimension(3) :: npixels8
  integer, dimension(12) :: icoltogrid
  integer :: ncolstogrid,igeom
  real    :: hmin,pixwidth,pixwidthx(3),rhominset,rhomin,gridmin,gridmax,gridmean
- logical :: inormalise,lowmem
+ real    :: mtot,mtotgrid,err,t2,t1
+ logical :: inormalise,lowmem,do_output
  logical, dimension(3) :: isperiodic
  character(len=len(labelcoord)), dimension(3) :: xlab
+ character(len=120) :: origin
 
+ dtime = real(time,kind=doub_prec)
+ do_output = .not.(trim(filename)=='none' .or. trim(outformat)=='none')
  !
  !--check for errors in input settings
  !
- if (ndim.lt.2 .or. ndim.gt.3) then
+ if (ndim < 2 .or. ndim > 3) then
     print "(/,a,i2,a,/)",' ERROR: SPH data has ',ndim,' spatial dimensions: cannot convert to 3D grid'
     return
  endif
@@ -106,29 +117,35 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  !
  !--get environment variable options
  !
- call get_splash2grid_options(ndim,ncolstogrid,icoltogrid,isperiodic,xlab)
+ if (present(icols)) then
+    icoltogrid(:) = 0
+    icoltogrid(1:size(icols)) = icols(:)
+    ncolstogrid = count(icols > 0)
+ else
+    call get_splash2grid_options(ndim,ncolstogrid,icoltogrid,isperiodic,xlab)
+ endif
  !
  !--check for errors
  !
  ierr = 0
  do i=1,ndim
-    if ((xmax(i)-xmin(i)).lt.tiny(0.)) then
+    if ((xmax(i)-xmin(i)) < tiny(0.)) then
        print "(a)",' ERROR: min = max in '//trim(label(ix(i)))//&
                    ' coordinate: cannot interpolate to zero-sized grid!'
        ierr = 1
     endif
  enddo
 
- if (irho.le.0 .or. irho.gt.ncolumns) then
+ if (irho <= 0 .or. irho > ncolumns) then
     print "(a)",' ERROR: density not found in data read.'
     ierr = 2
  endif
- if (ih.le.0 .or. ih.gt.ncolumns) then
+ if (ih <= 0 .or. ih > ncolumns) then
     print "(a)",' ERROR: smoothing length not found in data read.'
     ierr = 3
  endif
- if (ipmass.le.0 .or. ipmass.gt.ncolumns) then
-    if (all(masstype(:).lt.tiny(0.))) then
+ if (ipmass <= 0 .or. ipmass > ncolumns) then
+    if (all(masstype(:) < tiny(0.))) then
        print "(a)",' ERROR: particle masses not read as column, and mass per type not set.'
        ierr = 4
     endif
@@ -147,7 +164,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  ntoti = sum(npartoftype)
  ninterp = npartoftype(1)
  if (any(UseTypeInRenderings(2:ntypes).and.iplotpartoftype(2:ntypes)) &
-     .or. size(itype).gt.1) ninterp = ntoti
+     .or. size(itype) > 1) ninterp = ntoti
 
  allocate(weight(ninterp),stat=ierr)
  if (ierr /= 0) then
@@ -179,17 +196,17 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  if (product(npixels) > 0) then
     print*,'Using npixels = ',npixels,' from SPLASH_TO_GRID_NPIX'
  else
-    if (npixx.le.0) then
+    if (npixx <= 0) then
        print "(/,a)",' WARNING: number of pixels = 0, using automatic pixel numbers'
        hmin = 0.
        call minmaxmean_part(dat(:,ih:ih),weight,ninterp,partmin,partmax,partmean,nonzero=.true.)
        hmin = partmin(1)
-       if (hmin.gt.0. .and. igeom==igeom_cartesian) then
+       if (hmin > 0. .and. igeom==igeom_cartesian) then
           print*,'based on the minimum smoothing length of hmin = ',hmin
           npixels8(1:ndim) = int((xmax(1:ndim) - xmin(1:ndim))/hmin,kind=int8) + 1
-          if (ndim.eq.3) then
+          if (ndim==3) then
              print "(a,i6,2(' x',i6),a)",' requires ',npixels8(1:ndim),' pixels to capture the full resolution'
-             if (product(npixels8(1:ndim)).gt.512**3 .or. product(npixels8(1:ndim)).le.0) then
+             if (product(npixels8(1:ndim)) > 512**3 .or. product(npixels8(1:ndim)) <= 0) then
                 npixx = 512
                 print "(a,i4)",' but this is ridiculous, so instead we choose ',npixx
              else
@@ -197,7 +214,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
              endif
           else
              print "(a,i6,1(' x',i6),a)",' requires ',npixels8(1:ndim),' pixels to capture the full resolution'
-             if (product(npixels8(1:ndim)).gt.1024**ndim .or. product(npixels8(1:ndim)).le.0) then
+             if (product(npixels8(1:ndim)) > 1024**ndim .or. product(npixels8(1:ndim)) <= 0) then
                 npixx = 1024
                 print "(a,i4)",' but this is very large, so instead we choose ',npixx
              else
@@ -229,19 +246,19 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  !--work out how many columns will be written to file
  !
  nvec = 0
- if (ncolstogrid.gt.0) then
+ if (ncolstogrid > 0) then
     ncolsgrid = ncolstogrid
  elseif (interpolateall) then
     ncolsgrid = 0
     do i=1,ncolumns
-       if (.not.any(ix(1:ndim).eq.i) .and. i.ne.ih .and. i.ne.ipmass) then
+       if (.not.any(ix(1:ndim)==i) .and. i /= ih .and. i /= ipmass) then
           ncolsgrid = ncolsgrid + 1
        endif
     enddo
  else
-    if (ndimV.eq.ndim) then
-       if (ivx.gt.0 .and. ivx+ndimV-1.le.ncolumns) nvec = nvec + 1
-       if (iBfirst.gt.0 .and. iBfirst+ndimV-1.le.ncolumns) nvec = nvec + 1
+    if (ndimV==ndim) then
+       if (ivx > 0 .and. ivx+ndimV-1 <= ncolumns) nvec = nvec + 1
+       if (iBfirst > 0 .and. iBfirst+ndimV-1 <= ncolumns) nvec = nvec + 1
     endif
     ncolsgrid = 1 + ndimV*nvec
  endif
@@ -255,7 +272,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
     lowmem = .true.
  endif
 
- if (lowmem .and. nvec.gt.0) &
+ if (lowmem .and. nvec > 0) &
     print "(a,/)",' [doing velocity field components separately (low memory mode)]'
  !
  !--allocate memory for the grid
@@ -263,10 +280,10 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  if (allocated(datgrid))   deallocate(datgrid)
  if (allocated(datgrid2D)) deallocate(datgrid2D)
 
- if (ndim.eq.3) then
+ if (ndim==3) then
     write(*,"(a,i5,2(' x',i5),a)",advance='no') ' >>> allocating memory for ',npixels(1:ndim),' grid ...'
     allocate(datgrid(npixels(1),npixels(2),npixels(3)),stat=ierr)
- elseif (ndim.eq.2) then
+ elseif (ndim==2) then
     write(*,"(a,i5,1(' x',i5),a)",advance='no') ' >>> allocating memory for ',npixels(1:ndim),' grid ...'
     allocate(datgrid2D(npixels(1),npixels(2)),stat=ierr)
  endif
@@ -281,13 +298,18 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  !
  !--open grid file for output (also checks format is OK)
  !
- call open_gridfile_w(iunit,filename,outformat,ndim,ncolsgrid,npixels(1:ndim),time,ierr)
- if (ierr /= 0) then
-    print "(a)",' ERROR: could not open grid file for output, skipping...'
-    if (allocated(datgrid)) deallocate(datgrid)
-    if (allocated(datgrid)) deallocate(datgrid2D)
-    if (allocated(weight)) deallocate(weight)
-    return
+ if (do_output) then
+    origin='"splash to '//trim(outformat)//'" on file '//trim(filename)
+    xmind = xmin; xmaxd = xmax  ! convert to double precision
+    call open_gridfile_w(iunit,filename,outformat,ndim,ncolsgrid,npixels(1:ndim),&
+                         xmind(1:ndim),xmaxd(1:ndim),dtime,ierr)
+    if (ierr /= 0) then
+       print "(a)",' ERROR: could not open grid file for output, skipping...'
+       if (allocated(datgrid)) deallocate(datgrid)
+       if (allocated(datgrid)) deallocate(datgrid2D)
+       if (allocated(weight)) deallocate(weight)
+       return
+    endif
  endif
 
  fmtstring1 = "(12x,a20,1x,'    min    ',1x,'    max    ',1x,'    mean    ')"
@@ -302,7 +324,13 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  print fmtstring1,trim(label(irho))
  print fmtstring,' on parts:',partmin(1),partmax(1),partmean(1)
 
- if (ndim.eq.3) then
+ if (ipmass > 0.) then
+    mtot = sum(dat(1:ninterp,ipmass),mask=(icolourme(1:ninterp) > 0.))
+    print "(9x,a23,1x,es10.4,/)",'total mass on parts:',mtot
+ endif
+
+ if (ndim==3) then
+    call wall_time(t1)
     if (igeom /= igeom_cartesian) then
        call interpolate3Dgeom(igeom,dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),dat(1:ninterp,ix(3)),&
             dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,irho),icolourme,ninterp,&
@@ -311,8 +339,13 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
        call interpolate3D(dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),dat(1:ninterp,ix(3)),&
             dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,irho),icolourme,ninterp,&
             xmin(1),xmin(2),xmin(3),datgrid,npixels(1),npixels(2),npixels(3),&
-            pixwidth,pixwidth,inormalise,isperiodic(1),isperiodic(2),isperiodic(3))
+            pixwidthx(1),pixwidthx(2),pixwidthx(3),inormalise,&
+            isperiodic(1),isperiodic(2),isperiodic(3))
+       mtotgrid = sum(datgrid)*product(pixwidthx)
     endif
+    if (present(rhogrid)) rhogrid = datgrid
+    call wall_time(t2)
+    if (t2 - t1 > 1.) call print_time(t2-t1)
     !
     !--set minimum density on the grid
     !
@@ -321,37 +354,47 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
     call interpolate2D(dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),&
          dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,irho),icolourme,ninterp,&
          xmin(1),xmin(2),datgrid2D,npixels(1),npixels(2),&
-         pixwidth,pixwidth,inormalise,exact_rendering,isperiodic(1),isperiodic(2))
+         pixwidth,pixwidth,inormalise,exact_rendering,isperiodic(1),isperiodic(2),iverbose)
     !
     !--set minimum density on the grid
     !
     call minmaxmean_grid2D(datgrid2D,npixels,gridmin,gridmax,gridmean,nonzero=.true.)
+    mtot = sum(datgrid2D)*pixwidth**2*npixels(1)*npixels(2)
  endif
 
  print fmtstring1,trim(label(irho))
  print fmtstring,' on grid :',gridmin,gridmax,gridmean
+ !
+ !--print error if mass is not conserved
+ !
+ if (mtotgrid > 0.) then
+    print "(9x,a23,1x,es10.4,/)",'total mass on grid:',mtotgrid
+    err = 100.*(mtotgrid - mtot)/mtot
+    if (abs(err) > 1) print "(/,a,1pg7.1,a,/)",' WARNING! MASS NOT CONSERVED BY ',err,&
+    '% BY INTERPOLATION'
+ endif
 
  rhomin = gridmin
  rhominset = renvironment('SPLASH_TO_GRID_RHOMIN',errval=-1.)
 
  print*
- if (rhominset.ge.0.) then
+ if (rhominset >= 0.) then
     rhomin = rhominset
     print*,'enforcing minimum density on grid = ',rhomin
     print*,'(based on SPLASH_TO_GRID_RHOMIN setting)'
- elseif (rhomin.gt.0.) then
+ elseif (rhomin > 0.) then
     print*,'enforcing minimum density on grid = ',rhomin
     print*,'set SPLASH_TO_GRID_RHOMIN=minval to manually set this (e.g. to zero)'
  endif
 
- if (rhomin.gt.0.) then
+ if (rhomin > 0.) then
     nzero = 0
-    if (ndim.eq.3) then
+    if (ndim==3) then
        !$omp parallel do private(k,j,i) reduction(+:nzero) schedule(static)
        do k=1,npixels(3)
           do j=1,npixels(2)
              do i=1,npixels(1)
-                if (datgrid(i,j,k).le.tiny(datgrid)) then
+                if (datgrid(i,j,k) <= tiny(datgrid)) then
                    datgrid(i,j,k) = rhomin
                    nzero = nzero + 1
                 endif
@@ -362,7 +405,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
        !$omp parallel do private(j,i) reduction(+:nzero) schedule(static)
        do j=1,npixels(2)
           do i=1,npixels(1)
-             if (datgrid2D(i,j).le.tiny(datgrid2D)) then
+             if (datgrid2D(i,j) <= tiny(datgrid2D)) then
                 datgrid2D(i,j) = rhomin
                 nzero = nzero + 1
              endif
@@ -378,28 +421,30 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
  !--write density to grid data file
  !
  print*
- if (ndim.eq.3) then
-    if (lowmem .or. interpolateall .or. ncolstogrid.gt.0) then
+ if (ndim==3 .and. do_output) then
+    if (lowmem .or. interpolateall .or. ncolstogrid > 0) then
        call write_grid(iunit,filename,outformat,ndim,1,npixels,trim(label(irho)),&
-                       labelcoordsys(igeom),xlab,time,pixwidthx,xmin,ierr,dat=datgrid)
+                       labelcoordsys(igeom),xlab,dtime,pixwidthx,xmin,xmax,ierr,dat=datgrid,&
+                       tagline=tagline,origin=origin)
     endif
- else
+ elseif (do_output) then
     call write_grid(iunit,filename,outformat,ndim,1,npixels,trim(label(irho)),&
-                    labelcoordsys(igeom),xlab,time,pixwidthx,xmin,ierr,dat2D=datgrid2D)
+                    labelcoordsys(igeom),xlab,dtime,pixwidthx,xmin,xmax,ierr,dat2D=datgrid2D,&
+                    tagline=tagline,origin=origin)
  endif
  !
  !--interpolate remaining quantities to the 3D grid
  !
- if (interpolateall .or. ncolstogrid.gt.0) then
-    if (ncolstogrid.gt.0) then
+ if (interpolateall .or. ncolstogrid > 0) then
+    if (ncolstogrid > 0 .and. .not.present(icols)) then
        print "(/,a,i2,a)",' Interpolating ',ncolstogrid,' columns to grid from SPLASH_TO_GRID setting:'
        print "(' got SPLASH_TO_GRID=',10(i2,1x))",icoltogrid(1:ncolstogrid)
     endif
 
     do i=1,ncolumns
-       if ((ncolstogrid.gt.0 .and. any(icoltogrid.eq.i) .and. i.ne.irho) .or.  &
+       if ((ncolstogrid > 0 .and. any(icoltogrid==i) .and. i /= irho) .or.  &
            (interpolateall .and. &
-            .not.any(ix(:).eq.i) .and. i.ne.ih .and. i.ne.ipmass .and. i.ne.irho)) then
+            .not.any(ix(:)==i) .and. i /= ih .and. i /= ipmass .and. i /= irho)) then
 
           print "(/,a)",' interpolating '//trim(label(i))
           print fmtstring1,trim(label(i))
@@ -409,7 +454,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
           if (iszero(partmin,partmax,1)) then
              datgrid = 0.
           else
-             if (ndim.eq.3) then
+             if (ndim==3) then
                 if (igeom /= igeom_cartesian) then
                    call interpolate3Dgeom(igeom,dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),dat(1:ninterp,ix(3)),&
                         dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,i),icolourme,ninterp,&
@@ -418,42 +463,43 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
                    call interpolate3D(dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),dat(1:ninterp,ix(3)),&
                         dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,i),icolourme,ninterp,&
                         xmin(1),xmin(2),xmin(3),datgrid,npixels(1),npixels(2),npixels(3),&
-                        pixwidth,pixwidth,.true.,isperiodic(1),isperiodic(2),isperiodic(3))
+                        pixwidthx(1),pixwidthx(2),pixwidthx(3),.true.,isperiodic(1),isperiodic(2),isperiodic(3))
                 endif
+                if (present(dat3D)) dat3D = datgrid
              else
                 call interpolate2D(dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),&
                      dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,i),icolourme,ninterp,&
                      xmin(1),xmin(2),datgrid2D,npixels(1),npixels(2),&
-                     pixwidth,pixwidth,.true.,exact_rendering,isperiodic(1),isperiodic(2))
+                     pixwidth,pixwidth,.true.,exact_rendering,isperiodic(1),isperiodic(2),iverbose)
              endif
           endif
 
           !
           !--write gridded data to file
           !
-          if (ndim.eq.3) then
+          if (ndim==3) then
              call minmaxmean_grid(datgrid,npixels,gridmin,gridmax,gridmean,.false.)
              print fmtstring,' on grid :',gridmin,gridmax,gridmean
-             call write_grid(iunit,filename,outformat,ndim,1,npixels,trim(label(i)),&
-                  labelcoordsys(igeom),xlab,time,pixwidthx,xmin,ierr,dat=datgrid)
+             if (do_output) call write_grid(iunit,filename,outformat,ndim,1,npixels,trim(label(i)),&
+                  labelcoordsys(igeom),xlab,dtime,pixwidthx,xmin,xmax,ierr,dat=datgrid)
           else
              call minmaxmean_grid2D(datgrid2D,npixels,gridmin,gridmax,gridmean,.false.)
              print fmtstring,' on grid :',gridmin,gridmax,gridmean
-             call write_grid(iunit,filename,outformat,ndim,1,npixels,trim(label(i)),&
-                  labelcoordsys(igeom),xlab,time,pixwidthx,xmin,ierr,dat2D=datgrid2D)
+             if (do_output) call write_grid(iunit,filename,outformat,ndim,1,npixels,trim(label(i)),&
+                  labelcoordsys(igeom),xlab,dtime,pixwidthx,xmin,xmax,ierr,dat2D=datgrid2D)
           endif
        endif
     enddo
 
  else
 
-    if (nvec.gt.0) then
+    if (nvec > 0) then
 
        print "(/,a,i2,a)",' set SPLASH_TO_GRID=',irho,' to interpolate density ONLY and skip remaining columns'
        print "(a,i2,a)",  '     SPLASH_TO_GRID=6,8,10 to select particular columns'
 
        if (.not.lowmem) then
-          if (ndim.eq.3) then
+          if (ndim==3) then
              write(*,"(/,a,i5,2(' x',i5),a)",advance='no') ' >>> allocating memory for ',npixels(1:ndim),' x 3 grid ...'
              allocate(datgridvec(3,npixels(1),npixels(2),npixels(3)),stat=ierr)
           else
@@ -483,7 +529,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
              iloc = 0
              exit over_vec
           end select
-          if (iloc.le.0 .or. iloc.ge.ncolumns) cycle over_vec
+          if (iloc <= 0 .or. iloc >= ncolumns) cycle over_vec
 
           if (lowmem) then
 
@@ -496,7 +542,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
                 if (iszero(partmin,partmax,1)) then
                    datgrid = 0.
                 else
-                   if (ndim.eq.3) then
+                   if (ndim==3) then
                       if (igeom /= igeom_cartesian) then
                          call interpolate3Dgeom(igeom,dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),dat(1:ninterp,ix(3)),&
                            dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,i),icolourme,ninterp,&
@@ -505,29 +551,31 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
                          call interpolate3D(dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),dat(1:ninterp,ix(3)),&
                               dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,i),icolourme,ninterp,&
                               xmin(1),xmin(2),xmin(3),datgrid,npixels(1),npixels(2),npixels(3),&
-                              pixwidth,pixwidth,.true.,isperiodic(1),isperiodic(2),isperiodic(3))
+                              pixwidthx(1),pixwidthx(2),pixwidthx(3),.true.,isperiodic(1),isperiodic(2),isperiodic(3))
                       endif
                    else
                       call interpolate2D(dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),&
                            dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,i),icolourme,ninterp,&
                            xmin(1),xmin(2),datgrid2D,npixels(1),npixels(2),&
-                           pixwidth,pixwidth,.true.,exact_rendering,isperiodic(1),isperiodic(2))
+                           pixwidth,pixwidth,.true.,exact_rendering,isperiodic(1),isperiodic(2),iverbose)
                    endif
                 endif
 
                 !
                 !--write gridded data to file
                 !
-                if (ndim.eq.3) then
+                if (ndim==3) then
                    call minmaxmean_grid(datgrid,npixels,gridmin,gridmax,gridmean,.false.)
                    print fmtstring,' on grid :',gridmin,gridmax,gridmean
                    call write_grid(iunit,filename,outformat,ndim,1,npixels,trim(label(i)),&
-                        labelcoordsys(igeom),xlab,time,pixwidthx,xmin,ierr,dat=datgrid)
+                        labelcoordsys(igeom),xlab,dtime,pixwidthx,xmin,xmax,ierr,&
+                        dat=datgrid,tagline=tagline,origin=origin)
                 else
                    call minmaxmean_grid2D(datgrid2D,npixels,gridmin,gridmax,gridmean,.false.)
                    print fmtstring,' on grid :',gridmin,gridmax,gridmean
                    call write_grid(iunit,filename,outformat,ndim,1,npixels,trim(label(i)),&
-                        labelcoordsys(igeom),xlab,time,pixwidthx,xmin,ierr,dat2D=datgrid2D)
+                        labelcoordsys(igeom),xlab,dtime,pixwidthx,xmin,xmax,ierr,&
+                        dat2D=datgrid2D,tagline=tagline,origin=origin)
                 endif
              enddo
           else
@@ -541,7 +589,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
              if (iszero(partmin,partmax,ndimV)) then
                 datgridvec = 0.
              else
-                if (ndim.eq.3) then
+                if (ndim==3) then
                    if (igeom /= igeom_cartesian) then
                       call interpolate3Dgeom_vec(igeom,dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),dat(1:ninterp,ix(3)),&
                            dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,iloc:iloc+ndimV-1),icolourme,ninterp,&
@@ -550,7 +598,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
                       call interpolate3D_vec(dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),dat(1:ninterp,ix(3)),&
                         dat(1:ninterp,ih),weight(1:ninterp),dat(1:ninterp,iloc:iloc+ndimV-1),icolourme,ninterp,&
                         xmin(1),xmin(2),xmin(3),datgridvec,npixels(1),npixels(2),npixels(3),&
-                        pixwidth,pixwidth,.true.,isperiodic(1),isperiodic(2),isperiodic(3))
+                        pixwidthx(1),pixwidthx(2),pixwidthx(3),.true.,isperiodic(1),isperiodic(2),isperiodic(3))
                    endif
                 else
                    call interpolate2D_vec(dat(1:ninterp,ix(1)),dat(1:ninterp,ix(2)),&
@@ -560,7 +608,7 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
                 endif
              endif
 
-             if (ndim.eq.3) then
+             if (ndim==3) then
                 call minmaxmean_gridvec(datgridvec,npixels,ndimV,datmin,datmax,datmean)
              else
                 call minmaxmean_gridvec2D(datgridvec2D,npixels,ndimV,datmin,datmax,datmean)
@@ -571,15 +619,15 @@ subroutine convert_to_grid(time,dat,ntypes,npartoftype,masstype,itype,ncolumns,f
              !
              !--write result to grid file
              !
-             if (ndim.eq.3) then
+             if (ndim==3 .and. do_output) then
                 call write_grid(iunit,filename,outformat,ndim,ndimV,npixels,&
-                                label(irho),labelcoordsys(igeom),xlab,time,pixwidthx,xmin,ierr,&
-                                dat=datgrid,dat3D=datgridvec,label3D=label(iloc:iloc+ndimV))
-             else
+                                label(irho),labelcoordsys(igeom),xlab,dtime,pixwidthx,xmin,xmax,ierr,&
+                                dat=datgrid,dat3D=datgridvec,label3D=label(iloc:iloc+ndimV),tagline=tagline,origin=origin)
+             elseif (do_output) then
                 do i=1,ndimV
                    call write_grid(iunit,filename,outformat,ndim,ndimV,npixels,&
-                                   label(iloc+i-1),labelcoordsys(igeom),xlab,time,pixwidthx,&
-                                   xmin,ierr,dat2D=datgridvec2D(i,:,:))
+                                   label(iloc+i-1),labelcoordsys(igeom),xlab,dtime,pixwidthx,&
+                                   xmin,xmax,ierr,dat2D=datgridvec2D(i,:,:),tagline=tagline,origin=origin)
                 enddo
              endif
           endif
@@ -620,10 +668,10 @@ subroutine get_splash2grid_options(ndim,ncolstogrid,icoltogrid,isperiodic,xlab)
  ncolstogrid   = 0
  icoltogrid(:) = 0
  call envlist('SPLASH_TO_GRID',nstring,strings)
- if (nstring.gt.0) then
+ if (nstring > 0) then
     do i=1,nstring
        icol = ienvstring(strings(i))
-       if (ienvstring(strings(i)).gt.0) then
+       if (ienvstring(strings(i)) > 0) then
           ncolstogrid = ncolstogrid + 1
           icoltogrid(ncolstogrid) = icol
        endif
@@ -633,7 +681,7 @@ subroutine get_splash2grid_options(ndim,ncolstogrid,icoltogrid,isperiodic,xlab)
  !--for backwards compatibility, support the SPLASH_TO_GRID_DENSITY_ONLY option
  !  but only if SPLASH_TO_GRID is not set
  !
- if (ncolstogrid.eq.0 .and. lenvironment('SPLASH_TO_GRID_DENSITY_ONLY')) then
+ if (ncolstogrid==0 .and. lenvironment('SPLASH_TO_GRID_DENSITY_ONLY')) then
     ncolstogrid = 1
     icoltogrid(1) = irho
  endif
@@ -642,14 +690,14 @@ subroutine get_splash2grid_options(ndim,ncolstogrid,icoltogrid,isperiodic,xlab)
  !
  isperiodic(:) = .false.
  call envlist('SPLASH_TO_GRID_PERIODIC',nstring,strings)
- if (nstring.gt.ndim) then
+ if (nstring > ndim) then
     print "(a)",' ERROR in SPLASH_TO_GRID_PERIODIC setting'
     nstring = ndim
  endif
  do i=1,nstring
     isperiodic(i) = lenvstring(strings(i))
  enddo
- if (nstring.eq.1) isperiodic(2:ndim) = isperiodic(1)
+ if (nstring==1) isperiodic(2:ndim) = isperiodic(1)
 
  if (all(isperiodic(1:ndim))) then
     print "(/,a)",' using PERIODIC boundaries (from SPLASH_TO_GRID_PERIODIC setting)'
@@ -665,7 +713,7 @@ subroutine get_splash2grid_options(ndim,ncolstogrid,icoltogrid,isperiodic,xlab)
  else
     print "(/,a)",' using NON-PERIODIC boundaries'
     print "(a)",' (set SPLASH_TO_GRID_PERIODIC=yes for periodic'
-    if (ndim.eq.3) then
+    if (ndim==3) then
        print "(a)",'   or SPLASH_TO_GRID_PERIODIC=yes,no,yes for mixed)'
     else
        print "(a)",'   or SPLASH_TO_GRID_PERIODIC=yes,no for mixed)'
@@ -678,7 +726,7 @@ end subroutine
 ! calculate max and min and mean values on grid
 !-----------------------------------------------
 subroutine minmaxmean_grid(datgrid,npixels,gridmin,gridmax,gridmean,nonzero)
- real, dimension(:,:,:), intent(in) :: datgrid
+ real(doub_prec), dimension(:,:,:), intent(in) :: datgrid
  integer, dimension(3), intent(in)  :: npixels
  real, intent(out)                  :: gridmin,gridmax,gridmean
  logical, intent(in)                :: nonzero
@@ -698,7 +746,7 @@ subroutine minmaxmean_grid(datgrid,npixels,gridmin,gridmax,gridmean,nonzero)
           dati = datgrid(i,j,k)
           gridmax  = max(gridmax,dati)
           if (nonzero) then
-             if (dati.gt.tiny(0.)) gridmin  = min(gridmin,dati)
+             if (dati > tiny(0.)) gridmin  = min(gridmin,dati)
           else
              gridmin  = min(gridmin,dati)
           endif
@@ -734,7 +782,7 @@ subroutine minmaxmean_grid2D(datgrid,npixels,gridmin,gridmax,gridmean,nonzero)
        dati = datgrid(i,j)
        gridmax  = max(gridmax,dati)
        if (nonzero) then
-          if (dati.gt.tiny(0.)) gridmin  = min(gridmin,dati)
+          if (dati > tiny(0.)) gridmin  = min(gridmin,dati)
        else
           gridmin  = min(gridmin,dati)
        endif
@@ -751,7 +799,7 @@ end subroutine minmaxmean_grid2D
 ! (for vector quantities)
 !-----------------------------------------------
 subroutine minmaxmean_gridvec(datgridvec,npixels,jlen,gridmin,gridmax,gridmean)
- real, dimension(:,:,:,:), intent(in) :: datgridvec
+ real(doub_prec), dimension(:,:,:,:), intent(in) :: datgridvec
  integer, dimension(3), intent(in)    :: npixels
  integer, intent(in)                  :: jlen
  real, dimension(jlen), intent(out)   :: gridmin,gridmax,gridmean
@@ -849,12 +897,12 @@ subroutine minmaxmean_part(dat,weight,npart,partmin,partmax,partmean,nonzero)
  !!$omp private(i,j,partval)
  do i=1,npart
     !--only count particles used in the rendering
-    if (weight(i).gt.tiny(0.)) then
+    if (weight(i) > tiny(0.)) then
        np = np + 1
        do j=1,jlen
           partval = dat(i,j)
           if (usenonzero) then
-             if (partval.gt.tiny(0.)) partmin(j) = min(partmin(j),partval)
+             if (partval > tiny(0.)) partmin(j) = min(partmin(j),partval)
           else
              partmin(j) = min(partmin(j),partval)
           endif
@@ -865,7 +913,7 @@ subroutine minmaxmean_part(dat,weight,npart,partmin,partmax,partmean,nonzero)
  enddo
  !!$omp end parallel do
 
- if (np.gt.0) then
+ if (np > 0) then
     partmean(:) = partmean(:)/real(np)
  endif
 
@@ -878,8 +926,8 @@ logical function iszero(partmin,partmax,ndim)
  real, dimension(:), intent(in) :: partmin,partmax
  integer, intent(in)            :: ndim
 
- if (all(abs(partmin(1:ndim)).lt.tiny(0.)) .and. &
-     all(abs(partmax(1:ndim)).lt.tiny(0.))) then
+ if (all(abs(partmin(1:ndim)) < tiny(0.)) .and. &
+     all(abs(partmax(1:ndim)) < tiny(0.))) then
     iszero = .true.
     print "(a)",' min=max=0 on particles: skipping pointless interpolation and setting dat = 0.'
  else
