@@ -25,69 +25,69 @@
 ! Uses the function parser module
 !----------------------------------------------------------------------
 module exactfunction
-  implicit none
+ implicit none
 
 contains
 
 subroutine exact_function(string,xplot,yplot,time,ierr)
-  use fparser, only:initf,evalf,endf,EvalErrType,EvalErrMsg,rn
-  implicit none
-  character(len=*), intent(in) :: string
-  real, intent(in), dimension(:) :: xplot
-  real, intent(in)               :: time
-  real, intent(out), dimension(size(xplot)) :: yplot
-  integer, intent(out) :: ierr
-  integer :: i,j,nvars
-  real(kind=rn), dimension(:), allocatable     :: val
+ use fparser, only:initf,evalf,endf,EvalErrType,EvalErrMsg,rn
+ implicit none
+ character(len=*), intent(in) :: string
+ real, intent(in), dimension(:) :: xplot
+ real, intent(in)               :: time
+ real, intent(out), dimension(size(xplot)) :: yplot
+ integer, intent(out) :: ierr
+ integer :: i,j,nvars
+ real(kind=rn), dimension(:), allocatable     :: val
 
-  print "(a)",' Plotting function f(x) = '//trim(string)
-  if (len_trim(string).le.0) then
-     print "(a)",' *** ERROR: blank function string in exact_function call'
-     ierr = 1
-     return
-  endif
-  ierr = 0
-  !
-  !--work out how many subfunctions the string contains
-  !  and allocate memory for the sub function values appropriately
-  !
-  call get_nvars(string,nvars)
-  allocate(val(nvars),stat=ierr)
-  if (ierr /= 0) then
-     print "(a)",' ERROR allocating memory for ',nvars,' sub-functions in exact_function'
-     if (allocated(val)) deallocate(val)
-     return
-  endif
+ print "(a)",' Plotting function f(x) = '//trim(string)
+ if (len_trim(string) <= 0) then
+    print "(a)",' *** ERROR: blank function string in exact_function call'
+    ierr = 1
+    return
+ endif
+ ierr = 0
+ !
+ !--work out how many subfunctions the string contains
+ !  and allocate memory for the sub function values appropriately
+ !
+ call get_nvars(string,nvars)
+ allocate(val(nvars),stat=ierr)
+ if (ierr /= 0) then
+    print "(a)",' ERROR allocating memory for ',nvars,' sub-functions in exact_function'
+    if (allocated(val)) deallocate(val)
+    return
+ endif
 
-  call initf(nvars)
-  call parse_subfunctions(string,nvars,.false.,ierr)
+ call initf(nvars)
+ call parse_subfunctions(string,nvars,.false.,ierr)
 
-  if (EvalErrType.ne.0) then
-     print "(a)",' *** ERROR parsing function: '//trim(EvalerrMsg())//' ***'
-     ierr = EvalErrType
-  else
-     do i=1,size(xplot)
-        val(1) = xplot(i)                 ! type conversion here
-        val(2) = time                     ! type conversion here
+ if (EvalErrType /= 0) then
+    print "(a)",' *** ERROR parsing function: '//trim(EvalerrMsg())//' ***'
+    ierr = EvalErrType
+ else
+    do i=1,size(xplot)
+       val(1) = xplot(i)                 ! type conversion here
+       val(2) = time                     ! type conversion here
 
-        !--evaluate sub-functions in order of dependency
-        do j=3,nvars
-           val(j) = evalf(j,val(1:j-1))
-        enddo
-        yplot(i) = real(evalf(1,val(1:nvars)))  ! type conversion back
-        if (EvalErrType /= 0) ierr = EvalErrType
-     enddo
-     if (ierr.ne.0) then
-        print "(a)",' *** ERROR during function evaluation: '//trim(EvalerrMsg(ierr))
-        !--set exit error to zero so we plot the results anyway
-        ierr = 0
-     endif
-  endif
+       !--evaluate sub-functions in order of dependency
+       do j=3,nvars
+          val(j) = evalf(j,val(1:j-1))
+       enddo
+       yplot(i) = real(evalf(1,val(1:nvars)))  ! type conversion back
+       if (EvalErrType /= 0) ierr = EvalErrType
+    enddo
+    if (ierr /= 0) then
+       print "(a)",' *** ERROR during function evaluation: '//trim(EvalerrMsg(ierr))
+       !--set exit error to zero so we plot the results anyway
+       ierr = 0
+    endif
+ endif
 
-  call endf
-  if (allocated(val)) deallocate(val)
+ call endf
+ if (allocated(val)) deallocate(val)
 
-  return
+ return
 end subroutine exact_function
 
 !----------------------------------------------------------------
@@ -144,7 +144,7 @@ subroutine parse_subfunctions(string,nvars,check,ierr,verbose)
     if (string(j:j)==',') then
        !--sub functions must be of the form f(var) = val
        ieq = j + index(string(j+1:lstr),'=')
-       if (ieq.eq.j) then
+       if (ieq==j) then
           print "(a)",'*** Error in sub-function syntax, missing equals sign in comma-separated function list'
           ierr = 4
           return
@@ -152,7 +152,7 @@ subroutine parse_subfunctions(string,nvars,check,ierr,verbose)
        !--variable is what lies to left of equals sign
        ivars = ivars + 1
        var(ivars) = string(j+1:ieq-1)
-       if (len_trim(var(ivars)).le.0) then
+       if (len_trim(var(ivars)) <= 0) then
           print "(a)",'*** Error in sub-function syntax, blank variable '
           ierr = 3
           return
@@ -160,14 +160,14 @@ subroutine parse_subfunctions(string,nvars,check,ierr,verbose)
        !--function is what lies to right of equals sign
        if (check) then
           if (iverb) then
-             if (ivars.eq.ivarsinit+1) print "(a)",'Evaluating sub-functions in the order:'
+             if (ivars==ivarsinit+1) print "(a)",'Evaluating sub-functions in the order:'
              print "(a)",trim(var(ivars))//' = '//string(ieq+1:icommaprev-1)
           endif
           ierr = checkf(string(ieq+1:icommaprev-1),var(1:ivars-1))
           if (ierr /= 0) return
        else
           call parsef(ivars,string(ieq+1:icommaprev-1),var(1:ivars-1))
-          if (EvalErrType.ne.0) then
+          if (EvalErrType /= 0) then
              print "(a)",' *** ERROR parsing function: '//trim(EvalerrMsg())//' ***'
              ierr = EvalErrType
              return
@@ -176,7 +176,7 @@ subroutine parse_subfunctions(string,nvars,check,ierr,verbose)
        icommaprev = j
     endif
  enddo
- if (ivars.ne.nvars) then
+ if (ivars /= nvars) then
     print "(a)",' Internal consistency error in parse_subfunctions:'
     print*,' nvars ',ivars,' not equal to that obtained in get_nvars, ',nvars
  endif
@@ -184,11 +184,11 @@ subroutine parse_subfunctions(string,nvars,check,ierr,verbose)
 !--finally, check/parse combined function
 !
  if (check) then
-    if (ivars.ge.ivarsinit .and. iverb) print "(1x,a)",'f('//trim(var(1))//') = '//string(1:icommaprev-1)
+    if (ivars >= ivarsinit .and. iverb) print "(1x,a)",'f('//trim(var(1))//') = '//string(1:icommaprev-1)
     ierr = checkf(string(1:icommaprev-1),var(1:ivars))
  else
     call parsef(1,string(1:icommaprev-1),var(1:ivars))
-    if (EvalErrType.ne.0) then
+    if (EvalErrType /= 0) then
        print "(a)",' *** ERROR parsing function: '//trim(EvalerrMsg())//' ***'
        ierr = EvalErrType
     endif
