@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2019 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -26,12 +26,12 @@
 !-----------------------------------------------------------------
 module geomutils
  implicit none
- 
+
  public :: change_coords, changecoords, changeveccoords
  public :: set_coordlabels
- 
+
  private
- 
+
 contains
 
 !-----------------------------------------------------------------
@@ -59,10 +59,10 @@ subroutine change_coords(vals,ncols,ndim,icoords,icoordsnew,x0,v0)
  !--transform all vector quantities to new coord system
  iamvecprev = 0
  do icol=1,ncols - ndim + 1
-    if (iamvec(icol).gt.0 .and. iamvec(icol).ne.iamvecprev) then                          
+    if (iamvec(icol) > 0 .and. iamvec(icol) /= iamvecprev) then
        iamvecprev = iamvec(icol)
-       if (icol.eq.ivx) then
-          vec(1:ndim) = vals(iamvec(icol):iamvec(icol)+ndim-1) - v0(1:ndim)       
+       if (icol==ivx) then
+          vec(1:ndim) = vals(iamvec(icol):iamvec(icol)+ndim-1) - v0(1:ndim)
        else
           vec(1:ndim) = vals(iamvec(icol):iamvec(icol)+ndim-1)
        endif
@@ -70,7 +70,7 @@ subroutine change_coords(vals,ncols,ndim,icoords,icoordsnew,x0,v0)
        vals(iamvec(icol):iamvec(icol)+ndim-1) = vecnew(1:ndim)
     endif
  enddo
- 
+
 end subroutine change_coords
 
 !-------------------------------------------------------------------
@@ -94,28 +94,28 @@ subroutine changecoords(iplotx,iploty,iplotz,xplot,yplot,zplot,ntot,ndim,itrackp
  if (iscoordx .or. iscoordy) then
     if (debugmode) print*,'changing coords from ',trim(labelcoordsys(icoords)), &
                   ' to ',trim(labelcoordsys(icoordsnew))
-    if (itrackpart.gt.0) print*,'coords relative to particle ',itrackpart
+    if (itrackpart > 0) print*,'coords relative to particle ',itrackpart
 
     !--get offsets in range 1->ndim for the case where particle
     !  coords are not first in plot arrays
     ixcoord = iplotx - ix(1) + 1
-    if (iscoordx .and. (ixcoord.le.0 .or. ixcoord.gt.ndim)) then
+    if (iscoordx .and. (ixcoord <= 0 .or. ixcoord > ndim)) then
        print*,'ERROR in x coordinate offset in arrays: cannot change coordinate system'
        return
     endif
     iycoord = iploty - ix(1) + 1
-    if (iscoordy .and. (iycoord.le.0 .or. iycoord.gt.ndim)) then
+    if (iscoordy .and. (iycoord <= 0 .or. iycoord > ndim)) then
        print*,'ERROR in y coordinate offset in arrays: cannot change coordinate system'
        return
     endif
     izcoord = iplotz - ix(1) + 1
-    if (iscoordz .and. (izcoord.le.0 .or. izcoord.gt.ndim)) then
+    if (iscoordz .and. (izcoord <= 0 .or. izcoord > ndim)) then
        print*,'ERROR in z coordinate offset in arrays: cannot change coordinate system'
        return
     endif
 
     do j=1,ntot
-       if (itrackpart.gt.0 .and. itrackpart.le.ntot) then
+       if (itrackpart > 0 .and. itrackpart <= ntot) then
           xcoords(1:ndim) = dat(j,ix(1:ndim)) - dat(itrackpart,ix(1:ndim))
        else
           xcoords(1:ndim) = dat(j,ix(1:ndim)) - xorigin(1:ndim)
@@ -145,17 +145,17 @@ subroutine changeveccoords(iplot,xploti,ntot,ndim,itrackpart,dat)
  real, dimension(:,:), intent(in)  :: dat
  integer :: j
 
- if (iamvec(iplot).gt.0) then
-    if (iplot-iamvec(iplot)+1 .le. ndim) then
+ if (iamvec(iplot) > 0) then
+    if (iplot-iamvec(iplot)+1  <=  ndim) then
        if (debugmode) print*,'changing vector component from ', &
                       trim(labelcoordsys(icoords)),' to ',trim(labelcoordsys(icoordsnew))
-       if (itrackpart.gt.0 .and. iamvec(iplot).eq.ivx) then
+       if (itrackpart > 0 .and. iamvec(iplot)==ivx) then
           print*,'velocities relative to particle ',itrackpart
        endif
        do j=1,ntot
-          if (itrackpart.gt.0 .and. itrackpart.le.ntot) then
+          if (itrackpart > 0 .and. itrackpart <= ntot) then
              xcoords(1:ndim) = dat(j,ix(1:ndim)) - dat(itrackpart,ix(1:ndim))
-             if (iamvec(iplot).eq.ivx) then
+             if (iamvec(iplot)==ivx) then
                 vecin(1:ndim) = dat(j,iamvec(iplot):iamvec(iplot)+ndim-1) &
                                 - dat(itrackpart,iamvec(iplot):iamvec(iplot)+ndim-1)
              else
@@ -195,8 +195,8 @@ subroutine set_coordlabels(numplot)
 !--sanity check on icoordsnew...
 !  (should not be zero)
 !
- if (icoordsnew.le.0) then
-    if (icoords.gt.0) then
+ if (icoordsnew <= 0) then
+    if (icoords > 0) then
        icoordsnew = icoords
     else
        icoordsnew = 1
@@ -206,25 +206,25 @@ subroutine set_coordlabels(numplot)
 !--store the previous value of icoordsnew that was used
 !  last time we adjusted the labels
 !
- if (icoordsprev.lt.0) icoordsprev = icoordsnew
+ if (icoordsprev < 0) icoordsprev = icoordsnew
 !
 !--set coordinate and vector labels (depends on coordinate system)
 !
- if (icoordsnew.ne.icoords .or. icoordsnew.ne.icoordsprev) then
+ if (icoordsnew /= icoords .or. icoordsnew /= icoordsprev) then
 !
 !--here we are using a coordinate system that differs from the original
 !  one read from the code (must change labels appropriately)
 !
     if (debugmode) print*,'DEBUG: changing coordinate labels ...'
     do i=1,ndim
-       if (ix(i).gt.0) then
+       if (ix(i) > 0) then
           label(ix(i)) = labelcoord(i,icoordsnew)
           if (iRescale .and. coord_is_length(i,icoordsnew)) then
              label(ix(i)) = trim(label(ix(i)))//trim(unitslabel(ix(i)))
           endif
        endif
     enddo
-! elseif (icoordsnew.ne.icoordsprev) then
+! elseif (icoordsnew /= icoordsprev) then
 !!
 !!--here we are reverting back to the original coordinate system
 !!  so we have to re-read the original labels from the data read
@@ -234,13 +234,13 @@ subroutine set_coordlabels(numplot)
 !
 !--set vector labels if iamvec is set and the labels are the default
 !
- if (icoordsnew.gt.0) then
+ if (icoordsnew > 0) then
     do i=1,numplot
-       if (iamvec(i).ne.0 .and. &
-          (icoordsnew.ne.icoords .or. icoordsnew.ne.icoordsprev &
-           .or. index(label(i),trim(labeldefault)).ne.0)) then
-          if (i-iamvec(i)+1 .gt. 0) then
-             if (icoordsnew.eq.1) then
+       if (iamvec(i) /= 0 .and. &
+          (icoordsnew /= icoords .or. icoordsnew /= icoordsprev &
+           .or. index(label(i),trim(labeldefault)) /= 0)) then
+          if (i-iamvec(i)+1  >  0) then
+             if (icoordsnew==1) then
                 label(i) = trim(labelvec(iamvec(i)))//'_'//trim(labelcoord(i-iamvec(i)+1,icoordsnew))
              else
                 label(i) = trim(labelvec(iamvec(i)))//'_{'//trim(labelcoord(i-iamvec(i)+1,icoordsnew))//'}'
@@ -250,7 +250,7 @@ subroutine set_coordlabels(numplot)
                    trim(labelvec(iamvec(i)))//' in column ',i,' iamvec = ',iamvec(i)
           endif
           if (iRescale) then
-             label(i) = trim(label(i))//'\u'//trim(unitslabel(i))
+             label(i) = trim(label(i))//trim(unitslabel(i))
           endif
        endif
     enddo
