@@ -66,27 +66,27 @@ subroutine write_sphdata_gadget(time,dat,iamtype,ntotal,ntypes,npartoftype, &
 !
 !--check if we have enough data to write a GADGET dump
 !
- if (ndim.lt.3) then
+ if (ndim < 3) then
     print "(a)",' ERROR: ndim < 3 but must be 3 for GADGET data -- cannot write PHANTOM dump, skipping...'
     return
  endif
- if (any(ix(:).le.0)) then
+ if (any(ix(:) <= 0)) then
     print "(a)",' ERROR: position labels not set -- cannot write GADGET dump, skipping...'
     return
  endif
- if (ivx.le.0) then
+ if (ivx <= 0) then
     print "(a)",' ERROR: velocity not found in data -- cannot write GADGET dump, skipping...'
     return
  endif
- if (iutherm.le.0) then
+ if (iutherm <= 0) then
     print "(a)",' ERROR: thermal energy not found in data -- cannot write GADGET dump, skipping...'
     return
  endif
- if (irho.le.0) then
+ if (irho <= 0) then
     print "(a)",' ERROR: density not found in data -- cannot write GADGET dump, skipping...'
     return
  endif
- if (ih.le.0) then
+ if (ih <= 0) then
     print "(a)",' ERROR: smoothing length not found in data -- cannot write GADGET dump, skipping...'
     return
  endif
@@ -107,7 +107,7 @@ subroutine write_sphdata_gadget(time,dat,iamtype,ntotal,ntypes,npartoftype, &
     write(*,*) 'error: can''t create new dumpfile ',trim(outfile)
     return
  endif
- 
+
  massoftype(:)  = 0.
  nall(:)        = 0
  noftype(:)     = 0
@@ -118,7 +118,7 @@ subroutine write_sphdata_gadget(time,dat,iamtype,ntotal,ntypes,npartoftype, &
  boxsize   = abs(lim(ix(1),2) - lim(ix(1),1))
  unused(:) = 0
  dtime     = time
- 
+
  write(idump,err=100) noftype(1:6),massoftype(1:6),dtime,dumz, &
                       iflagsfr,iflagfeedback,nall(1:6),iflagcool,nfiles,boxsize, &
                       dumz,dumz,dumz,iflagsfr,iflagsfr,ncrap(1:6),iflagsfr,unused(:)
@@ -127,32 +127,32 @@ subroutine write_sphdata_gadget(time,dat,iamtype,ntotal,ntypes,npartoftype, &
  !
  nmasses = 0
  do j=1,6
-    if (massoftype(j).le.0.) then
+    if (massoftype(j) <= 0.) then
        nmasses = nmasses + noftype(j)
     endif
  enddo
  print*,'nmasses = ',nmasses
  ngas = npartoftype(1)
  print*,'ngas = ',ngas
- 
- if (ntotal > ngas .and. (size(iamtype).gt.1)) then
- !--must print the particles ordered by type
+
+ if (ntotal > ngas .and. (size(iamtype) > 1)) then
+    !--must print the particles ordered by type
     allocate(iorder(ntotal),stat=ierr)
     j = 0
     do itype=1,min(ntypes,6)
-       if (npartoftype(itype).gt.0) then
+       if (npartoftype(itype) > 0) then
           do i=1,ntotal
-             if (iamtype(i).eq.itype) then
+             if (iamtype(i)==itype) then
                 j = j + 1
                 iorder(j) = i
              endif
           enddo
        endif
     enddo
-    if (j.lt.ntotal) then
+    if (j < ntotal) then
        print*,' ERROR: too many particle types in conversion to gadget format'
        do i=j+1,ntotal
-          iorder(i) = i     
+          iorder(i) = i
        enddo
     endif
     write(idump,err=100) ((dat(iorder(i),ix(j)),j=1,3),i=1,ntotal)
@@ -172,7 +172,7 @@ subroutine write_sphdata_gadget(time,dat,iamtype,ntotal,ntypes,npartoftype, &
     write(idump,err=100) (dat(i,irho),   i=1,ngas)
     write(idump,err=100) (2.*dat(i,ih),  i=1,ngas)
  endif
- 
+
  print*,'finished writing file -- OK'
 
  close(unit=idump)
